# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/ad_group.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.common import custom_parameter_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_custom__parameter__pb2
from google.ads.google_ads.v1.proto.common import explorer_auto_optimizer_setting_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_explorer__auto__optimizer__setting__pb2
from google.ads.google_ads.v1.proto.common import targeting_setting_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_targeting__setting__pb2
from google.ads.google_ads.v1.proto.enums import ad_group_ad_rotation_mode_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_ad__group__ad__rotation__mode__pb2
from google.ads.google_ads.v1.proto.enums import ad_group_status_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_ad__group__status__pb2
from google.ads.google_ads.v1.proto.enums import ad_group_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_ad__group__type__pb2
from google.ads.google_ads.v1.proto.enums import bidding_source_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_bidding__source__pb2
from google.ads.google_ads.v1.proto.enums import targeting_dimension_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_targeting__dimension__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/ad_group.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\014AdGroupProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\n6google/ads/googleads_v1/proto/resources/ad_group.proto\x12!google.ads.googleads.v1.resources\x1a;google/ads/googleads_v1/proto/common/custom_parameter.proto\x1aJgoogle/ads/googleads_v1/proto/common/explorer_auto_optimizer_setting.proto\x1a<google/ads/googleads_v1/proto/common/targeting_setting.proto\x1a\x43google/ads/googleads_v1/proto/enums/ad_group_ad_rotation_mode.proto\x1a\x39google/ads/googleads_v1/proto/enums/ad_group_status.proto\x1a\x37google/ads/googleads_v1/proto/enums/ad_group_type.proto\x1a\x38google/ads/googleads_v1/proto/enums/bidding_source.proto\x1a=google/ads/googleads_v1/proto/enums/targeting_dimension.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\x90\r\n\x07\x41\x64Group\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12N\n\x06status\x18\x05 \x01(\x0e\x32>.google.ads.googleads.v1.enums.AdGroupStatusEnum.AdGroupStatus\x12H\n\x04type\x18\x0c \x01(\x0e\x32:.google.ads.googleads.v1.enums.AdGroupTypeEnum.AdGroupType\x12h\n\x10\x61\x64_rotation_mode\x18\x16 \x01(\x0e\x32N.google.ads.googleads.v1.enums.AdGroupAdRotationModeEnum.AdGroupAdRotationMode\x12\x33\n\rbase_ad_group\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\x15tracking_url_template\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12N\n\x15url_custom_parameters\x18\x06 \x03(\x0b\x32/.google.ads.googleads.v1.common.CustomParameter\x12.\n\x08\x63\x61mpaign\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\x0e\x63pc_bid_micros\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0e\x63pm_bid_micros\x18\x0f \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11target_cpa_micros\x18\x1b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0e\x63pv_bid_micros\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11target_cpm_micros\x18\x1a \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0btarget_roas\x18\x1e \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12;\n\x16percent_cpc_bid_micros\x18\x14 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x65\n\x1f\x65xplorer_auto_optimizer_setting\x18\x15 \x01(\x0b\x32<.google.ads.googleads.v1.common.ExplorerAutoOptimizerSetting\x12n\n\x1c\x64isplay_custom_bid_dimension\x18\x17 \x01(\x0e\x32H.google.ads.googleads.v1.enums.TargetingDimensionEnum.TargetingDimension\x12\x36\n\x10\x66inal_url_suffix\x18\x18 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12K\n\x11targeting_setting\x18\x19 \x01(\x0b\x32\x30.google.ads.googleads.v1.common.TargetingSetting\x12@\n\x1b\x65\x66\x66\x65\x63tive_target_cpa_micros\x18\x1c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x63\n\x1b\x65\x66\x66\x65\x63tive_target_cpa_source\x18\x1d \x01(\x0e\x32>.google.ads.googleads.v1.enums.BiddingSourceEnum.BiddingSource\x12;\n\x15\x65\x66\x66\x65\x63tive_target_roas\x18\x1f \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x64\n\x1c\x65\x66\x66\x65\x63tive_target_roas_source\x18  \x01(\x0e\x32>.google.ads.googleads.v1.enums.BiddingSourceEnum.BiddingSourceB\xf9\x01\n%com.google.ads.googleads.v1.resourcesB\x0c\x41\x64GroupProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_custom__parameter__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_explorer__auto__optimizer__setting__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_targeting__setting__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_ad__group__ad__rotation__mode__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_ad__group__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_ad__group__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_bidding__source__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_targeting__dimension__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_ADGROUP = _descriptor.Descriptor(
  name='AdGroup',
  full_name='google.ads.googleads.v1.resources.AdGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.AdGroup.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v1.resources.AdGroup.id', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v1.resources.AdGroup.name', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v1.resources.AdGroup.status', index=3,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.resources.AdGroup.type', index=4,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_rotation_mode', full_name='google.ads.googleads.v1.resources.AdGroup.ad_rotation_mode', index=5,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_ad_group', full_name='google.ads.googleads.v1.resources.AdGroup.base_ad_group', index=6,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracking_url_template', full_name='google.ads.googleads.v1.resources.AdGroup.tracking_url_template', index=7,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url_custom_parameters', full_name='google.ads.googleads.v1.resources.AdGroup.url_custom_parameters', index=8,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign', full_name='google.ads.googleads.v1.resources.AdGroup.campaign', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpc_bid_micros', full_name='google.ads.googleads.v1.resources.AdGroup.cpc_bid_micros', index=10,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpm_bid_micros', full_name='google.ads.googleads.v1.resources.AdGroup.cpm_bid_micros', index=11,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_cpa_micros', full_name='google.ads.googleads.v1.resources.AdGroup.target_cpa_micros', index=12,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpv_bid_micros', full_name='google.ads.googleads.v1.resources.AdGroup.cpv_bid_micros', index=13,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_cpm_micros', full_name='google.ads.googleads.v1.resources.AdGroup.target_cpm_micros', index=14,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_roas', full_name='google.ads.googleads.v1.resources.AdGroup.target_roas', index=15,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='percent_cpc_bid_micros', full_name='google.ads.googleads.v1.resources.AdGroup.percent_cpc_bid_micros', index=16,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='explorer_auto_optimizer_setting', full_name='google.ads.googleads.v1.resources.AdGroup.explorer_auto_optimizer_setting', index=17,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display_custom_bid_dimension', full_name='google.ads.googleads.v1.resources.AdGroup.display_custom_bid_dimension', index=18,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_url_suffix', full_name='google.ads.googleads.v1.resources.AdGroup.final_url_suffix', index=19,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='targeting_setting', full_name='google.ads.googleads.v1.resources.AdGroup.targeting_setting', index=20,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='effective_target_cpa_micros', full_name='google.ads.googleads.v1.resources.AdGroup.effective_target_cpa_micros', index=21,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='effective_target_cpa_source', full_name='google.ads.googleads.v1.resources.AdGroup.effective_target_cpa_source', index=22,
      number=29, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='effective_target_roas', full_name='google.ads.googleads.v1.resources.AdGroup.effective_target_roas', index=23,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='effective_target_roas_source', full_name='google.ads.googleads.v1.resources.AdGroup.effective_target_roas_source', index=24,
      number=32, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=661,
  serialized_end=2341,
)

_ADGROUP.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUP.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADGROUP.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_ad__group__status__pb2._ADGROUPSTATUSENUM_ADGROUPSTATUS
_ADGROUP.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_ad__group__type__pb2._ADGROUPTYPEENUM_ADGROUPTYPE
_ADGROUP.fields_by_name['ad_rotation_mode'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_ad__group__ad__rotation__mode__pb2._ADGROUPADROTATIONMODEENUM_ADGROUPADROTATIONMODE
_ADGROUP.fields_by_name['base_ad_group'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADGROUP.fields_by_name['tracking_url_template'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADGROUP.fields_by_name['url_custom_parameters'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_custom__parameter__pb2._CUSTOMPARAMETER
_ADGROUP.fields_by_name['campaign'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADGROUP.fields_by_name['cpc_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUP.fields_by_name['cpm_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUP.fields_by_name['target_cpa_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUP.fields_by_name['cpv_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUP.fields_by_name['target_cpm_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUP.fields_by_name['target_roas'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_ADGROUP.fields_by_name['percent_cpc_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUP.fields_by_name['explorer_auto_optimizer_setting'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_explorer__auto__optimizer__setting__pb2._EXPLORERAUTOOPTIMIZERSETTING
_ADGROUP.fields_by_name['display_custom_bid_dimension'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_targeting__dimension__pb2._TARGETINGDIMENSIONENUM_TARGETINGDIMENSION
_ADGROUP.fields_by_name['final_url_suffix'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADGROUP.fields_by_name['targeting_setting'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_targeting__setting__pb2._TARGETINGSETTING
_ADGROUP.fields_by_name['effective_target_cpa_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUP.fields_by_name['effective_target_cpa_source'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_bidding__source__pb2._BIDDINGSOURCEENUM_BIDDINGSOURCE
_ADGROUP.fields_by_name['effective_target_roas'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_ADGROUP.fields_by_name['effective_target_roas_source'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_bidding__source__pb2._BIDDINGSOURCEENUM_BIDDINGSOURCE
DESCRIPTOR.message_types_by_name['AdGroup'] = _ADGROUP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdGroup = _reflection.GeneratedProtocolMessageType('AdGroup', (_message.Message,), dict(
  DESCRIPTOR = _ADGROUP,
  __module__ = 'google.ads.googleads_v1.proto.resources.ad_group_pb2'
  ,
  __doc__ = """An ad group.
  
  
  Attributes:
      resource_name:
          The resource name of the ad group. Ad group resource names
          have the form:
          ``customers/{customer_id}/adGroups/{ad_group_id}``
      id:
          The ID of the ad group.
      name:
          The name of the ad group.  This field is required and should
          not be empty when creating new ad groups.  It must contain
          fewer than 255 UTF-8 full-width characters.  It must not
          contain any null (code point 0x0), NL line feed (code point
          0xA) or carriage return (code point 0xD) characters.
      status:
          The status of the ad group.
      type:
          The type of the ad group.
      ad_rotation_mode:
          The ad rotation mode of the ad group.
      base_ad_group:
          For draft or experiment ad groups, this field is the resource
          name of the base ad group from which this ad group was
          created. If a draft or experiment ad group does not have a
          base ad group, then this field is null.  For base ad groups,
          this field equals the ad group resource name.  This field is
          read-only.
      tracking_url_template:
          The URL template for constructing a tracking URL.
      url_custom_parameters:
          The list of mappings used to substitute custom parameter tags
          in a ``tracking_url_template``, ``final_urls``, or
          ``mobile_final_urls``.
      campaign:
          The campaign to which the ad group belongs.
      cpc_bid_micros:
          The maximum CPC (cost-per-click) bid.
      cpm_bid_micros:
          The maximum CPM (cost-per-thousand viewable impressions) bid.
      target_cpa_micros:
          The target CPA (cost-per-acquisition).
      cpv_bid_micros:
          The CPV (cost-per-view) bid.
      target_cpm_micros:
          Average amount in micros that the advertiser is willing to pay
          for every thousand times the ad is shown.
      target_roas:
          The target ROAS (return-on-ad-spend) override. If the ad
          group's campaign bidding strategy is a standard Target ROAS
          strategy, then this field overrides the target ROAS specified
          in the campaign's bidding strategy. Otherwise, this value is
          ignored.
      percent_cpc_bid_micros:
          The percent cpc bid amount, expressed as a fraction of the
          advertised price for some good or service. The valid range for
          the fraction is [0,1) and the value stored here is 1,000,000
          \* [fraction].
      explorer_auto_optimizer_setting:
          Settings for the Display Campaign Optimizer, initially termed
          "Explorer".
      display_custom_bid_dimension:
          Allows advertisers to specify a targeting dimension on which
          to place absolute bids. This is only applicable for campaigns
          that target only the display network and not search.
      final_url_suffix:
          URL template for appending params to Final URL.
      targeting_setting:
          Setting for targeting related features.
      effective_target_cpa_micros:
          The effective target CPA (cost-per-acquisition). This field is
          read-only.
      effective_target_cpa_source:
          Source of the effective target CPA. This field is read-only.
      effective_target_roas:
          The effective target ROAS (return-on-ad-spend). This field is
          read-only.
      effective_target_roas_source:
          Source of the effective target ROAS. This field is read-only.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.AdGroup)
  ))
_sym_db.RegisterMessage(AdGroup)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/enums/price_extension_price_unit.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/enums/price_extension_price_unit.proto',
  package='google.ads.googleads.v1.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v1.enumsB\034PriceExtensionPriceUnitProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V1.Enums\312\002\035Google\\Ads\\GoogleAds\\V1\\Enums\352\002!Google::Ads::GoogleAds::V1::Enums'),
  serialized_pb=_b('\nDgoogle/ads/googleads_v1/proto/enums/price_extension_price_unit.proto\x12\x1dgoogle.ads.googleads.v1.enums\x1a\x1cgoogle/api/annotations.proto\"\xac\x01\n\x1bPriceExtensionPriceUnitEnum\"\x8c\x01\n\x17PriceExtensionPriceUnit\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0c\n\x08PER_HOUR\x10\x02\x12\x0b\n\x07PER_DAY\x10\x03\x12\x0c\n\x08PER_WEEK\x10\x04\x12\r\n\tPER_MONTH\x10\x05\x12\x0c\n\x08PER_YEAR\x10\x06\x12\r\n\tPER_NIGHT\x10\x07\x42\xf1\x01\n!com.google.ads.googleads.v1.enumsB\x1cPriceExtensionPriceUnitProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V1.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V1\\Enums\xea\x02!Google::Ads::GoogleAds::V1::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_PRICEEXTENSIONPRICEUNITENUM_PRICEEXTENSIONPRICEUNIT = _descriptor.EnumDescriptor(
  name='PriceExtensionPriceUnit',
  full_name='google.ads.googleads.v1.enums.PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PER_HOUR', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PER_DAY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PER_WEEK', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PER_MONTH', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PER_YEAR', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PER_NIGHT', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=166,
  serialized_end=306,
)
_sym_db.RegisterEnumDescriptor(_PRICEEXTENSIONPRICEUNITENUM_PRICEEXTENSIONPRICEUNIT)


_PRICEEXTENSIONPRICEUNITENUM = _descriptor.Descriptor(
  name='PriceExtensionPriceUnitEnum',
  full_name='google.ads.googleads.v1.enums.PriceExtensionPriceUnitEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PRICEEXTENSIONPRICEUNITENUM_PRICEEXTENSIONPRICEUNIT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=306,
)

_PRICEEXTENSIONPRICEUNITENUM_PRICEEXTENSIONPRICEUNIT.containing_type = _PRICEEXTENSIONPRICEUNITENUM
DESCRIPTOR.message_types_by_name['PriceExtensionPriceUnitEnum'] = _PRICEEXTENSIONPRICEUNITENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PriceExtensionPriceUnitEnum = _reflection.GeneratedProtocolMessageType('PriceExtensionPriceUnitEnum', (_message.Message,), dict(
  DESCRIPTOR = _PRICEEXTENSIONPRICEUNITENUM,
  __module__ = 'google.ads.googleads_v1.proto.enums.price_extension_price_unit_pb2'
  ,
  __doc__ = """Container for enum describing price extension price unit.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.enums.PriceExtensionPriceUnitEnum)
  ))
_sym_db.RegisterMessage(PriceExtensionPriceUnitEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/campaign.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import bidding_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2
from google.ads.google_ads.v2.proto.common import custom_parameter_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_custom__parameter__pb2
from google.ads.google_ads.v2.proto.common import frequency_cap_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_frequency__cap__pb2
from google.ads.google_ads.v2.proto.common import real_time_bidding_setting_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_real__time__bidding__setting__pb2
from google.ads.google_ads.v2.proto.common import targeting_setting_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_targeting__setting__pb2
from google.ads.google_ads.v2.proto.enums import ad_serving_optimization_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__serving__optimization__status__pb2
from google.ads.google_ads.v2.proto.enums import advertising_channel_sub_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_advertising__channel__sub__type__pb2
from google.ads.google_ads.v2.proto.enums import advertising_channel_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_advertising__channel__type__pb2
from google.ads.google_ads.v2.proto.enums import app_campaign_app_store_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_app__campaign__app__store__pb2
from google.ads.google_ads.v2.proto.enums import app_campaign_bidding_strategy_goal_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_app__campaign__bidding__strategy__goal__type__pb2
from google.ads.google_ads.v2.proto.enums import bidding_strategy_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_bidding__strategy__type__pb2
from google.ads.google_ads.v2.proto.enums import brand_safety_suitability_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_brand__safety__suitability__pb2
from google.ads.google_ads.v2.proto.enums import campaign_experiment_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_campaign__experiment__type__pb2
from google.ads.google_ads.v2.proto.enums import campaign_serving_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_campaign__serving__status__pb2
from google.ads.google_ads.v2.proto.enums import campaign_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_campaign__status__pb2
from google.ads.google_ads.v2.proto.enums import negative_geo_target_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_negative__geo__target__type__pb2
from google.ads.google_ads.v2.proto.enums import payment_mode_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_payment__mode__pb2
from google.ads.google_ads.v2.proto.enums import positive_geo_target_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_positive__geo__target__type__pb2
from google.ads.google_ads.v2.proto.enums import vanity_pharma_display_url_mode_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_vanity__pharma__display__url__mode__pb2
from google.ads.google_ads.v2.proto.enums import vanity_pharma_text_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_vanity__pharma__text__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/campaign.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\rCampaignProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n6google/ads/googleads_v2/proto/resources/campaign.proto\x12!google.ads.googleads.v2.resources\x1a\x32google/ads/googleads_v2/proto/common/bidding.proto\x1a;google/ads/googleads_v2/proto/common/custom_parameter.proto\x1a\x38google/ads/googleads_v2/proto/common/frequency_cap.proto\x1a\x44google/ads/googleads_v2/proto/common/real_time_bidding_setting.proto\x1a<google/ads/googleads_v2/proto/common/targeting_setting.proto\x1aHgoogle/ads/googleads_v2/proto/enums/ad_serving_optimization_status.proto\x1a\x46google/ads/googleads_v2/proto/enums/advertising_channel_sub_type.proto\x1a\x42google/ads/googleads_v2/proto/enums/advertising_channel_type.proto\x1a@google/ads/googleads_v2/proto/enums/app_campaign_app_store.proto\x1aQgoogle/ads/googleads_v2/proto/enums/app_campaign_bidding_strategy_goal_type.proto\x1a?google/ads/googleads_v2/proto/enums/bidding_strategy_type.proto\x1a\x42google/ads/googleads_v2/proto/enums/brand_safety_suitability.proto\x1a\x42google/ads/googleads_v2/proto/enums/campaign_experiment_type.proto\x1a\x41google/ads/googleads_v2/proto/enums/campaign_serving_status.proto\x1a\x39google/ads/googleads_v2/proto/enums/campaign_status.proto\x1a\x42google/ads/googleads_v2/proto/enums/negative_geo_target_type.proto\x1a\x36google/ads/googleads_v2/proto/enums/payment_mode.proto\x1a\x42google/ads/googleads_v2/proto/enums/positive_geo_target_type.proto\x1aHgoogle/ads/googleads_v2/proto/enums/vanity_pharma_display_url_mode.proto\x1a<google/ads/googleads_v2/proto/enums/vanity_pharma_text.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xcf)\n\x08\x43\x61mpaign\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12P\n\x06status\x18\x05 \x01(\x0e\x32@.google.ads.googleads.v2.enums.CampaignStatusEnum.CampaignStatus\x12\x66\n\x0eserving_status\x18\x15 \x01(\x0e\x32N.google.ads.googleads.v2.enums.CampaignServingStatusEnum.CampaignServingStatus\x12\x82\x01\n\x1e\x61\x64_serving_optimization_status\x18\x08 \x01(\x0e\x32Z.google.ads.googleads.v2.enums.AdServingOptimizationStatusEnum.AdServingOptimizationStatus\x12r\n\x18\x61\x64vertising_channel_type\x18\t \x01(\x0e\x32P.google.ads.googleads.v2.enums.AdvertisingChannelTypeEnum.AdvertisingChannelType\x12|\n\x1c\x61\x64vertising_channel_sub_type\x18\n \x01(\x0e\x32V.google.ads.googleads.v2.enums.AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType\x12;\n\x15tracking_url_template\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12N\n\x15url_custom_parameters\x18\x0c \x03(\x0b\x32/.google.ads.googleads.v2.common.CustomParameter\x12Y\n\x19real_time_bidding_setting\x18\' \x01(\x0b\x32\x36.google.ads.googleads.v2.common.RealTimeBiddingSetting\x12U\n\x10network_settings\x18\x0e \x01(\x0b\x32;.google.ads.googleads.v2.resources.Campaign.NetworkSettings\x12S\n\rhotel_setting\x18  \x01(\x0b\x32<.google.ads.googleads.v2.resources.Campaign.HotelSettingInfo\x12g\n\x1a\x64ynamic_search_ads_setting\x18! \x01(\x0b\x32\x43.google.ads.googleads.v2.resources.Campaign.DynamicSearchAdsSetting\x12U\n\x10shopping_setting\x18$ \x01(\x0b\x32;.google.ads.googleads.v2.resources.Campaign.ShoppingSetting\x12K\n\x11targeting_setting\x18+ \x01(\x0b\x32\x30.google.ads.googleads.v2.common.TargetingSetting\x12\x61\n\x17geo_target_type_setting\x18/ \x01(\x0b\x32@.google.ads.googleads.v2.resources.Campaign.GeoTargetTypeSetting\x12\\\n\x14\x61pp_campaign_setting\x18\x33 \x01(\x0b\x32>.google.ads.googleads.v2.resources.Campaign.AppCampaignSetting\x12,\n\x06labels\x18\x35 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12i\n\x0f\x65xperiment_type\x18\x11 \x01(\x0e\x32P.google.ads.googleads.v2.enums.CampaignExperimentTypeEnum.CampaignExperimentType\x12\x33\n\rbase_campaign\x18\x1c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0f\x63\x61mpaign_budget\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12i\n\x15\x62idding_strategy_type\x18\x16 \x01(\x0e\x32J.google.ads.googleads.v2.enums.BiddingStrategyTypeEnum.BiddingStrategyType\x12\x30\n\nstart_date\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x65nd_date\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10\x66inal_url_suffix\x18& \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12I\n\x0e\x66requency_caps\x18( \x03(\x0b\x32\x31.google.ads.googleads.v2.common.FrequencyCapEntry\x12x\n\x1evideo_brand_safety_suitability\x18* \x01(\x0e\x32P.google.ads.googleads.v2.enums.BrandSafetySuitabilityEnum.BrandSafetySuitability\x12O\n\rvanity_pharma\x18, \x01(\x0b\x32\x38.google.ads.googleads.v2.resources.Campaign.VanityPharma\x12\x61\n\x16selective_optimization\x18- \x01(\x0b\x32\x41.google.ads.googleads.v2.resources.Campaign.SelectiveOptimization\x12U\n\x10tracking_setting\x18. \x01(\x0b\x32;.google.ads.googleads.v2.resources.Campaign.TrackingSetting\x12P\n\x0cpayment_mode\x18\x34 \x01(\x0e\x32:.google.ads.googleads.v2.enums.PaymentModeEnum.PaymentMode\x12\x38\n\x10\x62idding_strategy\x18\x17 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x12@\n\ncommission\x18\x31 \x01(\x0b\x32*.google.ads.googleads.v2.common.CommissionH\x00\x12?\n\nmanual_cpc\x18\x18 \x01(\x0b\x32).google.ads.googleads.v2.common.ManualCpcH\x00\x12?\n\nmanual_cpm\x18\x19 \x01(\x0b\x32).google.ads.googleads.v2.common.ManualCpmH\x00\x12?\n\nmanual_cpv\x18% \x01(\x0b\x32).google.ads.googleads.v2.common.ManualCpvH\x00\x12S\n\x14maximize_conversions\x18\x1e \x01(\x0b\x32\x33.google.ads.googleads.v2.common.MaximizeConversionsH\x00\x12\\\n\x19maximize_conversion_value\x18\x1f \x01(\x0b\x32\x37.google.ads.googleads.v2.common.MaximizeConversionValueH\x00\x12?\n\ntarget_cpa\x18\x1a \x01(\x0b\x32).google.ads.googleads.v2.common.TargetCpaH\x00\x12X\n\x17target_impression_share\x18\x30 \x01(\x0b\x32\x35.google.ads.googleads.v2.common.TargetImpressionShareH\x00\x12\x41\n\x0btarget_roas\x18\x1d \x01(\x0b\x32*.google.ads.googleads.v2.common.TargetRoasH\x00\x12\x43\n\x0ctarget_spend\x18\x1b \x01(\x0b\x32+.google.ads.googleads.v2.common.TargetSpendH\x00\x12\x41\n\x0bpercent_cpc\x18\" \x01(\x0b\x32*.google.ads.googleads.v2.common.PercentCpcH\x00\x12?\n\ntarget_cpm\x18) \x01(\x0b\x32).google.ads.googleads.v2.common.TargetCpmH\x00\x1a\x85\x02\n\x0fNetworkSettings\x12\x38\n\x14target_google_search\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x15target_search_network\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12:\n\x16target_content_network\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x1dtarget_partner_search_network\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1aH\n\x10HotelSettingInfo\x12\x34\n\x0fhotel_center_id\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1aQ\n\x15SelectiveOptimization\x12\x38\n\x12\x63onversion_actions\x18\x01 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x1a\xea\x01\n\x17\x44ynamicSearchAdsSetting\x12\x31\n\x0b\x64omain_name\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rlanguage_code\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x16use_supplied_urls_only\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x05\x66\x65\x65\x64s\x18\x05 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x1a\xb0\x02\n\x12\x41ppCampaignSetting\x12\x8c\x01\n\x1a\x62idding_strategy_goal_type\x18\x01 \x01(\x0e\x32h.google.ads.googleads.v2.enums.AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType\x12,\n\x06\x61pp_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12]\n\tapp_store\x18\x03 \x01(\x0e\x32J.google.ads.googleads.v2.enums.AppCampaignAppStoreEnum.AppCampaignAppStore\x1a\xe2\x01\n\x0fShoppingSetting\x12\x30\n\x0bmerchant_id\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\rsales_country\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x11\x63\x61mpaign_priority\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x30\n\x0c\x65nable_local\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\x45\n\x0fTrackingSetting\x12\x32\n\x0ctracking_url\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x1a\xfa\x01\n\x14GeoTargetTypeSetting\x12p\n\x18positive_geo_target_type\x18\x01 \x01(\x0e\x32N.google.ads.googleads.v2.enums.PositiveGeoTargetTypeEnum.PositiveGeoTargetType\x12p\n\x18negative_geo_target_type\x18\x02 \x01(\x0e\x32N.google.ads.googleads.v2.enums.NegativeGeoTargetTypeEnum.NegativeGeoTargetType\x1a\xf3\x01\n\x0cVanityPharma\x12\x80\x01\n\x1evanity_pharma_display_url_mode\x18\x01 \x01(\x0e\x32X.google.ads.googleads.v2.enums.VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlMode\x12`\n\x12vanity_pharma_text\x18\x02 \x01(\x0e\x32\x44.google.ads.googleads.v2.enums.VanityPharmaTextEnum.VanityPharmaTextB\x1b\n\x19\x63\x61mpaign_bidding_strategyB\xfa\x01\n%com.google.ads.googleads.v2.resourcesB\rCampaignProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_custom__parameter__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_frequency__cap__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_real__time__bidding__setting__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_targeting__setting__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__serving__optimization__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_advertising__channel__sub__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_advertising__channel__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_app__campaign__app__store__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_app__campaign__bidding__strategy__goal__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_bidding__strategy__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_brand__safety__suitability__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_campaign__experiment__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_campaign__serving__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_campaign__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_negative__geo__target__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_payment__mode__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_positive__geo__target__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_vanity__pharma__display__url__mode__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_vanity__pharma__text__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CAMPAIGN_NETWORKSETTINGS = _descriptor.Descriptor(
  name='NetworkSettings',
  full_name='google.ads.googleads.v2.resources.Campaign.NetworkSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_google_search', full_name='google.ads.googleads.v2.resources.Campaign.NetworkSettings.target_google_search', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_search_network', full_name='google.ads.googleads.v2.resources.Campaign.NetworkSettings.target_search_network', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_content_network', full_name='google.ads.googleads.v2.resources.Campaign.NetworkSettings.target_content_network', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_partner_search_network', full_name='google.ads.googleads.v2.resources.Campaign.NetworkSettings.target_partner_search_network', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5014,
  serialized_end=5275,
)

_CAMPAIGN_HOTELSETTINGINFO = _descriptor.Descriptor(
  name='HotelSettingInfo',
  full_name='google.ads.googleads.v2.resources.Campaign.HotelSettingInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hotel_center_id', full_name='google.ads.googleads.v2.resources.Campaign.HotelSettingInfo.hotel_center_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5277,
  serialized_end=5349,
)

_CAMPAIGN_SELECTIVEOPTIMIZATION = _descriptor.Descriptor(
  name='SelectiveOptimization',
  full_name='google.ads.googleads.v2.resources.Campaign.SelectiveOptimization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='conversion_actions', full_name='google.ads.googleads.v2.resources.Campaign.SelectiveOptimization.conversion_actions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5351,
  serialized_end=5432,
)

_CAMPAIGN_DYNAMICSEARCHADSSETTING = _descriptor.Descriptor(
  name='DynamicSearchAdsSetting',
  full_name='google.ads.googleads.v2.resources.Campaign.DynamicSearchAdsSetting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='domain_name', full_name='google.ads.googleads.v2.resources.Campaign.DynamicSearchAdsSetting.domain_name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language_code', full_name='google.ads.googleads.v2.resources.Campaign.DynamicSearchAdsSetting.language_code', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_supplied_urls_only', full_name='google.ads.googleads.v2.resources.Campaign.DynamicSearchAdsSetting.use_supplied_urls_only', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feeds', full_name='google.ads.googleads.v2.resources.Campaign.DynamicSearchAdsSetting.feeds', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5435,
  serialized_end=5669,
)

_CAMPAIGN_APPCAMPAIGNSETTING = _descriptor.Descriptor(
  name='AppCampaignSetting',
  full_name='google.ads.googleads.v2.resources.Campaign.AppCampaignSetting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bidding_strategy_goal_type', full_name='google.ads.googleads.v2.resources.Campaign.AppCampaignSetting.bidding_strategy_goal_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='google.ads.googleads.v2.resources.Campaign.AppCampaignSetting.app_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_store', full_name='google.ads.googleads.v2.resources.Campaign.AppCampaignSetting.app_store', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5672,
  serialized_end=5976,
)

_CAMPAIGN_SHOPPINGSETTING = _descriptor.Descriptor(
  name='ShoppingSetting',
  full_name='google.ads.googleads.v2.resources.Campaign.ShoppingSetting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='merchant_id', full_name='google.ads.googleads.v2.resources.Campaign.ShoppingSetting.merchant_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sales_country', full_name='google.ads.googleads.v2.resources.Campaign.ShoppingSetting.sales_country', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_priority', full_name='google.ads.googleads.v2.resources.Campaign.ShoppingSetting.campaign_priority', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_local', full_name='google.ads.googleads.v2.resources.Campaign.ShoppingSetting.enable_local', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5979,
  serialized_end=6205,
)

_CAMPAIGN_TRACKINGSETTING = _descriptor.Descriptor(
  name='TrackingSetting',
  full_name='google.ads.googleads.v2.resources.Campaign.TrackingSetting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tracking_url', full_name='google.ads.googleads.v2.resources.Campaign.TrackingSetting.tracking_url', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6207,
  serialized_end=6276,
)

_CAMPAIGN_GEOTARGETTYPESETTING = _descriptor.Descriptor(
  name='GeoTargetTypeSetting',
  full_name='google.ads.googleads.v2.resources.Campaign.GeoTargetTypeSetting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='positive_geo_target_type', full_name='google.ads.googleads.v2.resources.Campaign.GeoTargetTypeSetting.positive_geo_target_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='negative_geo_target_type', full_name='google.ads.googleads.v2.resources.Campaign.GeoTargetTypeSetting.negative_geo_target_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6279,
  serialized_end=6529,
)

_CAMPAIGN_VANITYPHARMA = _descriptor.Descriptor(
  name='VanityPharma',
  full_name='google.ads.googleads.v2.resources.Campaign.VanityPharma',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vanity_pharma_display_url_mode', full_name='google.ads.googleads.v2.resources.Campaign.VanityPharma.vanity_pharma_display_url_mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vanity_pharma_text', full_name='google.ads.googleads.v2.resources.Campaign.VanityPharma.vanity_pharma_text', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6532,
  serialized_end=6775,
)

_CAMPAIGN = _descriptor.Descriptor(
  name='Campaign',
  full_name='google.ads.googleads.v2.resources.Campaign',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.Campaign.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v2.resources.Campaign.id', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v2.resources.Campaign.name', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v2.resources.Campaign.status', index=3,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serving_status', full_name='google.ads.googleads.v2.resources.Campaign.serving_status', index=4,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_serving_optimization_status', full_name='google.ads.googleads.v2.resources.Campaign.ad_serving_optimization_status', index=5,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='advertising_channel_type', full_name='google.ads.googleads.v2.resources.Campaign.advertising_channel_type', index=6,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='advertising_channel_sub_type', full_name='google.ads.googleads.v2.resources.Campaign.advertising_channel_sub_type', index=7,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracking_url_template', full_name='google.ads.googleads.v2.resources.Campaign.tracking_url_template', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url_custom_parameters', full_name='google.ads.googleads.v2.resources.Campaign.url_custom_parameters', index=9,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='real_time_bidding_setting', full_name='google.ads.googleads.v2.resources.Campaign.real_time_bidding_setting', index=10,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='network_settings', full_name='google.ads.googleads.v2.resources.Campaign.network_settings', index=11,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_setting', full_name='google.ads.googleads.v2.resources.Campaign.hotel_setting', index=12,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dynamic_search_ads_setting', full_name='google.ads.googleads.v2.resources.Campaign.dynamic_search_ads_setting', index=13,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shopping_setting', full_name='google.ads.googleads.v2.resources.Campaign.shopping_setting', index=14,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='targeting_setting', full_name='google.ads.googleads.v2.resources.Campaign.targeting_setting', index=15,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_type_setting', full_name='google.ads.googleads.v2.resources.Campaign.geo_target_type_setting', index=16,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_campaign_setting', full_name='google.ads.googleads.v2.resources.Campaign.app_campaign_setting', index=17,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='google.ads.googleads.v2.resources.Campaign.labels', index=18,
      number=53, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experiment_type', full_name='google.ads.googleads.v2.resources.Campaign.experiment_type', index=19,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_campaign', full_name='google.ads.googleads.v2.resources.Campaign.base_campaign', index=20,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_budget', full_name='google.ads.googleads.v2.resources.Campaign.campaign_budget', index=21,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bidding_strategy_type', full_name='google.ads.googleads.v2.resources.Campaign.bidding_strategy_type', index=22,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='google.ads.googleads.v2.resources.Campaign.start_date', index=23,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='google.ads.googleads.v2.resources.Campaign.end_date', index=24,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_url_suffix', full_name='google.ads.googleads.v2.resources.Campaign.final_url_suffix', index=25,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frequency_caps', full_name='google.ads.googleads.v2.resources.Campaign.frequency_caps', index=26,
      number=40, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video_brand_safety_suitability', full_name='google.ads.googleads.v2.resources.Campaign.video_brand_safety_suitability', index=27,
      number=42, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vanity_pharma', full_name='google.ads.googleads.v2.resources.Campaign.vanity_pharma', index=28,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selective_optimization', full_name='google.ads.googleads.v2.resources.Campaign.selective_optimization', index=29,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracking_setting', full_name='google.ads.googleads.v2.resources.Campaign.tracking_setting', index=30,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payment_mode', full_name='google.ads.googleads.v2.resources.Campaign.payment_mode', index=31,
      number=52, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bidding_strategy', full_name='google.ads.googleads.v2.resources.Campaign.bidding_strategy', index=32,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commission', full_name='google.ads.googleads.v2.resources.Campaign.commission', index=33,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manual_cpc', full_name='google.ads.googleads.v2.resources.Campaign.manual_cpc', index=34,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manual_cpm', full_name='google.ads.googleads.v2.resources.Campaign.manual_cpm', index=35,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manual_cpv', full_name='google.ads.googleads.v2.resources.Campaign.manual_cpv', index=36,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maximize_conversions', full_name='google.ads.googleads.v2.resources.Campaign.maximize_conversions', index=37,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maximize_conversion_value', full_name='google.ads.googleads.v2.resources.Campaign.maximize_conversion_value', index=38,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_cpa', full_name='google.ads.googleads.v2.resources.Campaign.target_cpa', index=39,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_impression_share', full_name='google.ads.googleads.v2.resources.Campaign.target_impression_share', index=40,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_roas', full_name='google.ads.googleads.v2.resources.Campaign.target_roas', index=41,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_spend', full_name='google.ads.googleads.v2.resources.Campaign.target_spend', index=42,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='percent_cpc', full_name='google.ads.googleads.v2.resources.Campaign.percent_cpc', index=43,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_cpm', full_name='google.ads.googleads.v2.resources.Campaign.target_cpm', index=44,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CAMPAIGN_NETWORKSETTINGS, _CAMPAIGN_HOTELSETTINGINFO, _CAMPAIGN_SELECTIVEOPTIMIZATION, _CAMPAIGN_DYNAMICSEARCHADSSETTING, _CAMPAIGN_APPCAMPAIGNSETTING, _CAMPAIGN_SHOPPINGSETTING, _CAMPAIGN_TRACKINGSETTING, _CAMPAIGN_GEOTARGETTYPESETTING, _CAMPAIGN_VANITYPHARMA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='campaign_bidding_strategy', full_name='google.ads.googleads.v2.resources.Campaign.campaign_bidding_strategy',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1477,
  serialized_end=6804,
)

_CAMPAIGN_NETWORKSETTINGS.fields_by_name['target_google_search'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CAMPAIGN_NETWORKSETTINGS.fields_by_name['target_search_network'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CAMPAIGN_NETWORKSETTINGS.fields_by_name['target_content_network'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CAMPAIGN_NETWORKSETTINGS.fields_by_name['target_partner_search_network'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CAMPAIGN_NETWORKSETTINGS.containing_type = _CAMPAIGN
_CAMPAIGN_HOTELSETTINGINFO.fields_by_name['hotel_center_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGN_HOTELSETTINGINFO.containing_type = _CAMPAIGN
_CAMPAIGN_SELECTIVEOPTIMIZATION.fields_by_name['conversion_actions'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGN_SELECTIVEOPTIMIZATION.containing_type = _CAMPAIGN
_CAMPAIGN_DYNAMICSEARCHADSSETTING.fields_by_name['domain_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGN_DYNAMICSEARCHADSSETTING.fields_by_name['language_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGN_DYNAMICSEARCHADSSETTING.fields_by_name['use_supplied_urls_only'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CAMPAIGN_DYNAMICSEARCHADSSETTING.fields_by_name['feeds'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGN_DYNAMICSEARCHADSSETTING.containing_type = _CAMPAIGN
_CAMPAIGN_APPCAMPAIGNSETTING.fields_by_name['bidding_strategy_goal_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_app__campaign__bidding__strategy__goal__type__pb2._APPCAMPAIGNBIDDINGSTRATEGYGOALTYPEENUM_APPCAMPAIGNBIDDINGSTRATEGYGOALTYPE
_CAMPAIGN_APPCAMPAIGNSETTING.fields_by_name['app_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGN_APPCAMPAIGNSETTING.fields_by_name['app_store'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_app__campaign__app__store__pb2._APPCAMPAIGNAPPSTOREENUM_APPCAMPAIGNAPPSTORE
_CAMPAIGN_APPCAMPAIGNSETTING.containing_type = _CAMPAIGN
_CAMPAIGN_SHOPPINGSETTING.fields_by_name['merchant_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGN_SHOPPINGSETTING.fields_by_name['sales_country'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGN_SHOPPINGSETTING.fields_by_name['campaign_priority'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_CAMPAIGN_SHOPPINGSETTING.fields_by_name['enable_local'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CAMPAIGN_SHOPPINGSETTING.containing_type = _CAMPAIGN
_CAMPAIGN_TRACKINGSETTING.fields_by_name['tracking_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGN_TRACKINGSETTING.containing_type = _CAMPAIGN
_CAMPAIGN_GEOTARGETTYPESETTING.fields_by_name['positive_geo_target_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_positive__geo__target__type__pb2._POSITIVEGEOTARGETTYPEENUM_POSITIVEGEOTARGETTYPE
_CAMPAIGN_GEOTARGETTYPESETTING.fields_by_name['negative_geo_target_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_negative__geo__target__type__pb2._NEGATIVEGEOTARGETTYPEENUM_NEGATIVEGEOTARGETTYPE
_CAMPAIGN_GEOTARGETTYPESETTING.containing_type = _CAMPAIGN
_CAMPAIGN_VANITYPHARMA.fields_by_name['vanity_pharma_display_url_mode'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_vanity__pharma__display__url__mode__pb2._VANITYPHARMADISPLAYURLMODEENUM_VANITYPHARMADISPLAYURLMODE
_CAMPAIGN_VANITYPHARMA.fields_by_name['vanity_pharma_text'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_vanity__pharma__text__pb2._VANITYPHARMATEXTENUM_VANITYPHARMATEXT
_CAMPAIGN_VANITYPHARMA.containing_type = _CAMPAIGN
_CAMPAIGN.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGN.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGN.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_campaign__status__pb2._CAMPAIGNSTATUSENUM_CAMPAIGNSTATUS
_CAMPAIGN.fields_by_name['serving_status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_campaign__serving__status__pb2._CAMPAIGNSERVINGSTATUSENUM_CAMPAIGNSERVINGSTATUS
_CAMPAIGN.fields_by_name['ad_serving_optimization_status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__serving__optimization__status__pb2._ADSERVINGOPTIMIZATIONSTATUSENUM_ADSERVINGOPTIMIZATIONSTATUS
_CAMPAIGN.fields_by_name['advertising_channel_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_advertising__channel__type__pb2._ADVERTISINGCHANNELTYPEENUM_ADVERTISINGCHANNELTYPE
_CAMPAIGN.fields_by_name['advertising_channel_sub_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_advertising__channel__sub__type__pb2._ADVERTISINGCHANNELSUBTYPEENUM_ADVERTISINGCHANNELSUBTYPE
_CAMPAIGN.fields_by_name['tracking_url_template'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGN.fields_by_name['url_custom_parameters'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_custom__parameter__pb2._CUSTOMPARAMETER
_CAMPAIGN.fields_by_name['real_time_bidding_setting'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_real__time__bidding__setting__pb2._REALTIMEBIDDINGSETTING
_CAMPAIGN.fields_by_name['network_settings'].message_type = _CAMPAIGN_NETWORKSETTINGS
_CAMPAIGN.fields_by_name['hotel_setting'].message_type = _CAMPAIGN_HOTELSETTINGINFO
_CAMPAIGN.fields_by_name['dynamic_search_ads_setting'].message_type = _CAMPAIGN_DYNAMICSEARCHADSSETTING
_CAMPAIGN.fields_by_name['shopping_setting'].message_type = _CAMPAIGN_SHOPPINGSETTING
_CAMPAIGN.fields_by_name['targeting_setting'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_targeting__setting__pb2._TARGETINGSETTING
_CAMPAIGN.fields_by_name['geo_target_type_setting'].message_type = _CAMPAIGN_GEOTARGETTYPESETTING
_CAMPAIGN.fields_by_name['app_campaign_setting'].message_type = _CAMPAIGN_APPCAMPAIGNSETTING
_CAMPAIGN.fields_by_name['labels'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGN.fields_by_name['experiment_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_campaign__experiment__type__pb2._CAMPAIGNEXPERIMENTTYPEENUM_CAMPAIGNEXPERIMENTTYPE
_CAMPAIGN.fields_by_name['base_campaign'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGN.fields_by_name['campaign_budget'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGN.fields_by_name['bidding_strategy_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_bidding__strategy__type__pb2._BIDDINGSTRATEGYTYPEENUM_BIDDINGSTRATEGYTYPE
_CAMPAIGN.fields_by_name['start_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGN.fields_by_name['end_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGN.fields_by_name['final_url_suffix'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGN.fields_by_name['frequency_caps'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_frequency__cap__pb2._FREQUENCYCAPENTRY
_CAMPAIGN.fields_by_name['video_brand_safety_suitability'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_brand__safety__suitability__pb2._BRANDSAFETYSUITABILITYENUM_BRANDSAFETYSUITABILITY
_CAMPAIGN.fields_by_name['vanity_pharma'].message_type = _CAMPAIGN_VANITYPHARMA
_CAMPAIGN.fields_by_name['selective_optimization'].message_type = _CAMPAIGN_SELECTIVEOPTIMIZATION
_CAMPAIGN.fields_by_name['tracking_setting'].message_type = _CAMPAIGN_TRACKINGSETTING
_CAMPAIGN.fields_by_name['payment_mode'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_payment__mode__pb2._PAYMENTMODEENUM_PAYMENTMODE
_CAMPAIGN.fields_by_name['bidding_strategy'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGN.fields_by_name['commission'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2._COMMISSION
_CAMPAIGN.fields_by_name['manual_cpc'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2._MANUALCPC
_CAMPAIGN.fields_by_name['manual_cpm'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2._MANUALCPM
_CAMPAIGN.fields_by_name['manual_cpv'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2._MANUALCPV
_CAMPAIGN.fields_by_name['maximize_conversions'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2._MAXIMIZECONVERSIONS
_CAMPAIGN.fields_by_name['maximize_conversion_value'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2._MAXIMIZECONVERSIONVALUE
_CAMPAIGN.fields_by_name['target_cpa'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2._TARGETCPA
_CAMPAIGN.fields_by_name['target_impression_share'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2._TARGETIMPRESSIONSHARE
_CAMPAIGN.fields_by_name['target_roas'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2._TARGETROAS
_CAMPAIGN.fields_by_name['target_spend'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2._TARGETSPEND
_CAMPAIGN.fields_by_name['percent_cpc'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2._PERCENTCPC
_CAMPAIGN.fields_by_name['target_cpm'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2._TARGETCPM
_CAMPAIGN.oneofs_by_name['campaign_bidding_strategy'].fields.append(
  _CAMPAIGN.fields_by_name['bidding_strategy'])
_CAMPAIGN.fields_by_name['bidding_strategy'].containing_oneof = _CAMPAIGN.oneofs_by_name['campaign_bidding_strategy']
_CAMPAIGN.oneofs_by_name['campaign_bidding_strategy'].fields.append(
  _CAMPAIGN.fields_by_name['commission'])
_CAMPAIGN.fields_by_name['commission'].containing_oneof = _CAMPAIGN.oneofs_by_name['campaign_bidding_strategy']
_CAMPAIGN.oneofs_by_name['campaign_bidding_strategy'].fields.append(
  _CAMPAIGN.fields_by_name['manual_cpc'])
_CAMPAIGN.fields_by_name['manual_cpc'].containing_oneof = _CAMPAIGN.oneofs_by_name['campaign_bidding_strategy']
_CAMPAIGN.oneofs_by_name['campaign_bidding_strategy'].fields.append(
  _CAMPAIGN.fields_by_name['manual_cpm'])
_CAMPAIGN.fields_by_name['manual_cpm'].containing_oneof = _CAMPAIGN.oneofs_by_name['campaign_bidding_strategy']
_CAMPAIGN.oneofs_by_name['campaign_bidding_strategy'].fields.append(
  _CAMPAIGN.fields_by_name['manual_cpv'])
_CAMPAIGN.fields_by_name['manual_cpv'].containing_oneof = _CAMPAIGN.oneofs_by_name['campaign_bidding_strategy']
_CAMPAIGN.oneofs_by_name['campaign_bidding_strategy'].fields.append(
  _CAMPAIGN.fields_by_name['maximize_conversions'])
_CAMPAIGN.fields_by_name['maximize_conversions'].containing_oneof = _CAMPAIGN.oneofs_by_name['campaign_bidding_strategy']
_CAMPAIGN.oneofs_by_name['campaign_bidding_strategy'].fields.append(
  _CAMPAIGN.fields_by_name['maximize_conversion_value'])
_CAMPAIGN.fields_by_name['maximize_conversion_value'].containing_oneof = _CAMPAIGN.oneofs_by_name['campaign_bidding_strategy']
_CAMPAIGN.oneofs_by_name['campaign_bidding_strategy'].fields.append(
  _CAMPAIGN.fields_by_name['target_cpa'])
_CAMPAIGN.fields_by_name['target_cpa'].containing_oneof = _CAMPAIGN.oneofs_by_name['campaign_bidding_strategy']
_CAMPAIGN.oneofs_by_name['campaign_bidding_strategy'].fields.append(
  _CAMPAIGN.fields_by_name['target_impression_share'])
_CAMPAIGN.fields_by_name['target_impression_share'].containing_oneof = _CAMPAIGN.oneofs_by_name['campaign_bidding_strategy']
_CAMPAIGN.oneofs_by_name['campaign_bidding_strategy'].fields.append(
  _CAMPAIGN.fields_by_name['target_roas'])
_CAMPAIGN.fields_by_name['target_roas'].containing_oneof = _CAMPAIGN.oneofs_by_name['campaign_bidding_strategy']
_CAMPAIGN.oneofs_by_name['campaign_bidding_strategy'].fields.append(
  _CAMPAIGN.fields_by_name['target_spend'])
_CAMPAIGN.fields_by_name['target_spend'].containing_oneof = _CAMPAIGN.oneofs_by_name['campaign_bidding_strategy']
_CAMPAIGN.oneofs_by_name['campaign_bidding_strategy'].fields.append(
  _CAMPAIGN.fields_by_name['percent_cpc'])
_CAMPAIGN.fields_by_name['percent_cpc'].containing_oneof = _CAMPAIGN.oneofs_by_name['campaign_bidding_strategy']
_CAMPAIGN.oneofs_by_name['campaign_bidding_strategy'].fields.append(
  _CAMPAIGN.fields_by_name['target_cpm'])
_CAMPAIGN.fields_by_name['target_cpm'].containing_oneof = _CAMPAIGN.oneofs_by_name['campaign_bidding_strategy']
DESCRIPTOR.message_types_by_name['Campaign'] = _CAMPAIGN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Campaign = _reflection.GeneratedProtocolMessageType('Campaign', (_message.Message,), dict(

  NetworkSettings = _reflection.GeneratedProtocolMessageType('NetworkSettings', (_message.Message,), dict(
    DESCRIPTOR = _CAMPAIGN_NETWORKSETTINGS,
    __module__ = 'google.ads.googleads_v2.proto.resources.campaign_pb2'
    ,
    __doc__ = """The network settings for the campaign.
    
    
    Attributes:
        target_google_search:
            Whether ads will be served with google.com search results.
        target_search_network:
            Whether ads will be served on partner sites in the Google
            Search Network (requires ``target_google_search`` to also be
            ``true``).
        target_content_network:
            Whether ads will be served on specified placements in the
            Google Display Network. Placements are specified using the
            Placement criterion.
        target_partner_search_network:
            Whether ads will be served on the Google Partner Network. This
            is available only to some select Google partner accounts.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.Campaign.NetworkSettings)
    ))
  ,

  HotelSettingInfo = _reflection.GeneratedProtocolMessageType('HotelSettingInfo', (_message.Message,), dict(
    DESCRIPTOR = _CAMPAIGN_HOTELSETTINGINFO,
    __module__ = 'google.ads.googleads_v2.proto.resources.campaign_pb2'
    ,
    __doc__ = """Campaign-level settings for hotel ads.
    
    
    Attributes:
        hotel_center_id:
            The linked Hotel Center account.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.Campaign.HotelSettingInfo)
    ))
  ,

  SelectiveOptimization = _reflection.GeneratedProtocolMessageType('SelectiveOptimization', (_message.Message,), dict(
    DESCRIPTOR = _CAMPAIGN_SELECTIVEOPTIMIZATION,
    __module__ = 'google.ads.googleads_v2.proto.resources.campaign_pb2'
    ,
    __doc__ = """Selective optimization setting for this campaign, which includes a set
    of conversion actions to optimize this campaign towards.
    
    
    Attributes:
        conversion_actions:
            The selected set of conversion actions for optimizing this
            campaign.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.Campaign.SelectiveOptimization)
    ))
  ,

  DynamicSearchAdsSetting = _reflection.GeneratedProtocolMessageType('DynamicSearchAdsSetting', (_message.Message,), dict(
    DESCRIPTOR = _CAMPAIGN_DYNAMICSEARCHADSSETTING,
    __module__ = 'google.ads.googleads_v2.proto.resources.campaign_pb2'
    ,
    __doc__ = """The setting for controlling Dynamic Search Ads (DSA).
    
    
    Attributes:
        domain_name:
            The Internet domain name that this setting represents, e.g.,
            "google.com" or "www.google.com".
        language_code:
            The language code specifying the language of the domain, e.g.,
            "en".
        use_supplied_urls_only:
            Whether the campaign uses advertiser supplied URLs
            exclusively.
        feeds:
            The list of page feeds associated with the campaign.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.Campaign.DynamicSearchAdsSetting)
    ))
  ,

  AppCampaignSetting = _reflection.GeneratedProtocolMessageType('AppCampaignSetting', (_message.Message,), dict(
    DESCRIPTOR = _CAMPAIGN_APPCAMPAIGNSETTING,
    __module__ = 'google.ads.googleads_v2.proto.resources.campaign_pb2'
    ,
    __doc__ = """Campaign level settings for App Campaigns.
    
    
    Attributes:
        bidding_strategy_goal_type:
            Represents the goal which the bidding strategy of this app
            campaign should optimize towards.
        app_id:
            A string that uniquely identifies a mobile application.
        app_store:
            The application store that distributes this specific app.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.Campaign.AppCampaignSetting)
    ))
  ,

  ShoppingSetting = _reflection.GeneratedProtocolMessageType('ShoppingSetting', (_message.Message,), dict(
    DESCRIPTOR = _CAMPAIGN_SHOPPINGSETTING,
    __module__ = 'google.ads.googleads_v2.proto.resources.campaign_pb2'
    ,
    __doc__ = """The setting for Shopping campaigns. Defines the universe of products
    that can be advertised by the campaign, and how this campaign interacts
    with other Shopping campaigns.
    
    
    Attributes:
        merchant_id:
            ID of the Merchant Center account. This field is required for
            create operations. This field is immutable for Shopping
            campaigns.
        sales_country:
            Sales country of products to include in the campaign. This
            field is required for Shopping campaigns. This field is
            immutable. This field is optional for non-Shopping campaigns,
            but it must be equal to 'ZZ' if set.
        campaign_priority:
            Priority of the campaign. Campaigns with numerically higher
            priorities take precedence over those with lower priorities.
            This field is required for Shopping campaigns, with values
            between 0 and 2, inclusive. This field is optional for Smart
            Shopping campaigns, but must be equal to 3 if set.
        enable_local:
            Whether to include local products.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.Campaign.ShoppingSetting)
    ))
  ,

  TrackingSetting = _reflection.GeneratedProtocolMessageType('TrackingSetting', (_message.Message,), dict(
    DESCRIPTOR = _CAMPAIGN_TRACKINGSETTING,
    __module__ = 'google.ads.googleads_v2.proto.resources.campaign_pb2'
    ,
    __doc__ = """Campaign level settings for tracking information.
    
    
    Attributes:
        tracking_url:
            The url used for dynamic tracking.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.Campaign.TrackingSetting)
    ))
  ,

  GeoTargetTypeSetting = _reflection.GeneratedProtocolMessageType('GeoTargetTypeSetting', (_message.Message,), dict(
    DESCRIPTOR = _CAMPAIGN_GEOTARGETTYPESETTING,
    __module__ = 'google.ads.googleads_v2.proto.resources.campaign_pb2'
    ,
    __doc__ = """Represents a collection of settings related to ads geotargeting.
    
    
    Attributes:
        positive_geo_target_type:
            The setting used for positive geotargeting in this particular
            campaign.
        negative_geo_target_type:
            The setting used for negative geotargeting in this particular
            campaign.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.Campaign.GeoTargetTypeSetting)
    ))
  ,

  VanityPharma = _reflection.GeneratedProtocolMessageType('VanityPharma', (_message.Message,), dict(
    DESCRIPTOR = _CAMPAIGN_VANITYPHARMA,
    __module__ = 'google.ads.googleads_v2.proto.resources.campaign_pb2'
    ,
    __doc__ = """Describes how unbranded pharma ads will be displayed.
    
    
    Attributes:
        vanity_pharma_display_url_mode:
            The display mode for vanity pharma URLs.
        vanity_pharma_text:
            The text that will be displayed in display URL of the text ad
            when website description is the selected display mode for
            vanity pharma URLs.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.Campaign.VanityPharma)
    ))
  ,
  DESCRIPTOR = _CAMPAIGN,
  __module__ = 'google.ads.googleads_v2.proto.resources.campaign_pb2'
  ,
  __doc__ = """A campaign.
  
  
  Attributes:
      resource_name:
          The resource name of the campaign. Campaign resource names
          have the form:
          ``customers/{customer_id}/campaigns/{campaign_id}``
      id:
          The ID of the campaign.
      name:
          The name of the campaign.  This field is required and should
          not be empty when creating new campaigns.  It must not contain
          any null (code point 0x0), NL line feed (code point 0xA) or
          carriage return (code point 0xD) characters.
      status:
          The status of the campaign.  When a new campaign is added, the
          status defaults to ENABLED.
      serving_status:
          The ad serving status of the campaign.
      ad_serving_optimization_status:
          The ad serving optimization status of the campaign.
      advertising_channel_type:
          The primary serving target for ads within the campaign. The
          targeting options can be refined in ``network_settings``.
          This field is required and should not be empty when creating
          new campaigns.  Can be set only when creating campaigns. After
          the campaign is created, the field can not be changed.
      advertising_channel_sub_type:
          Optional refinement to ``advertising_channel_type``. Must be a
          valid sub-type of the parent channel type.  Can be set only
          when creating campaigns. After campaign is created, the field
          can not be changed.
      tracking_url_template:
          The URL template for constructing a tracking URL.
      url_custom_parameters:
          The list of mappings used to substitute custom parameter tags
          in a ``tracking_url_template``, ``final_urls``, or
          ``mobile_final_urls``.
      real_time_bidding_setting:
          Settings for Real-Time Bidding, a feature only available for
          campaigns targeting the Ad Exchange network.
      network_settings:
          The network settings for the campaign.
      hotel_setting:
          The hotel setting for the campaign.
      dynamic_search_ads_setting:
          The setting for controlling Dynamic Search Ads (DSA).
      shopping_setting:
          The setting for controlling Shopping campaigns.
      targeting_setting:
          Setting for targeting related features.
      geo_target_type_setting:
          The setting for ads geotargeting.
      app_campaign_setting:
          The setting related to App Campaign.
      labels:
          The resource names of labels attached to this campaign.
      experiment_type:
          The type of campaign: normal, draft, or experiment.
      base_campaign:
          The resource name of the base campaign of a draft or
          experiment campaign. For base campaigns, this is equal to
          ``resource_name``.  This field is read-only.
      campaign_budget:
          The budget of the campaign.
      bidding_strategy_type:
          The type of bidding strategy.  A bidding strategy can be
          created by setting either the bidding scheme to create a
          standard bidding strategy or the ``bidding_strategy`` field to
          create a portfolio bidding strategy.  This field is read-only.
      start_date:
          The date when campaign started.  This field must not be used
          in WHERE clauses.
      end_date:
          The date when campaign ended.  This field must not be used in
          WHERE clauses.
      final_url_suffix:
          Suffix used to append query parameters to landing pages that
          are served with parallel tracking.
      frequency_caps:
          A list that limits how often each user will see this
          campaign's ads.
      video_brand_safety_suitability:
          3-Tier Brand Safety setting for the campaign.
      vanity_pharma:
          Describes how unbranded pharma ads will be displayed.
      selective_optimization:
          Selective optimization setting for this campaign, which
          includes a set of conversion actions to optimize this campaign
          towards.
      tracking_setting:
          Campaign level settings for tracking information.
      payment_mode:
          Payment mode for the campaign.
      campaign_bidding_strategy:
          The bidding strategy for the campaign.  Must be either
          portfolio (created via BiddingStrategy service) or standard,
          that is embedded into the campaign.
      bidding_strategy:
          Portfolio bidding strategy used by campaign.
      commission:
          Commission is an automatic bidding strategy in which the
          advertiser pays a certain portion of the conversion value.
      manual_cpc:
          Standard Manual CPC bidding strategy. Manual click-based
          bidding where user pays per click.
      manual_cpm:
          Standard Manual CPM bidding strategy. Manual impression-based
          bidding where user pays per thousand impressions.
      manual_cpv:
          A bidding strategy that pays a configurable amount per video
          view.
      maximize_conversions:
          Standard Maximize Conversions bidding strategy that
          automatically maximizes number of conversions given a daily
          budget.
      maximize_conversion_value:
          Standard Maximize Conversion Value bidding strategy that
          automatically sets bids to maximize revenue while spending
          your budget.
      target_cpa:
          Standard Target CPA bidding strategy that automatically sets
          bids to help get as many conversions as possible at the target
          cost-per-acquisition (CPA) you set.
      target_impression_share:
          Target Impression Share bidding strategy. An automated bidding
          strategy that sets bids to achieve a desired percentage of
          impressions.
      target_roas:
          Standard Target ROAS bidding strategy that automatically
          maximizes revenue while averaging a specific target return on
          ad spend (ROAS).
      target_spend:
          Standard Target Spend bidding strategy that automatically sets
          your bids to help get as many clicks as possible within your
          budget.
      percent_cpc:
          Standard Percent Cpc bidding strategy where bids are a
          fraction of the advertised price for some good or service.
      target_cpm:
          A bidding strategy that automatically optimizes cost per
          thousand impressions.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.Campaign)
  ))
_sym_db.RegisterMessage(Campaign)
_sym_db.RegisterMessage(Campaign.NetworkSettings)
_sym_db.RegisterMessage(Campaign.HotelSettingInfo)
_sym_db.RegisterMessage(Campaign.SelectiveOptimization)
_sym_db.RegisterMessage(Campaign.DynamicSearchAdsSetting)
_sym_db.RegisterMessage(Campaign.AppCampaignSetting)
_sym_db.RegisterMessage(Campaign.ShoppingSetting)
_sym_db.RegisterMessage(Campaign.TrackingSetting)
_sym_db.RegisterMessage(Campaign.GeoTargetTypeSetting)
_sym_db.RegisterMessage(Campaign.VanityPharma)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import extension_feed_item_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_extension__feed__item__pb2
from google.ads.google_ads.v2.proto.services import extension_feed_item_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_extension__feed__item__service__pb2


class ExtensionFeedItemServiceStub(object):
  """Proto file describing the ExtensionFeedItem service.

  Service to manage extension feed items.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetExtensionFeedItem = channel.unary_unary(
        '/google.ads.googleads.v2.services.ExtensionFeedItemService/GetExtensionFeedItem',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_extension__feed__item__service__pb2.GetExtensionFeedItemRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_extension__feed__item__pb2.ExtensionFeedItem.FromString,
        )
    self.MutateExtensionFeedItems = channel.unary_unary(
        '/google.ads.googleads.v2.services.ExtensionFeedItemService/MutateExtensionFeedItems',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_extension__feed__item__service__pb2.MutateExtensionFeedItemsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_extension__feed__item__service__pb2.MutateExtensionFeedItemsResponse.FromString,
        )


class ExtensionFeedItemServiceServicer(object):
  """Proto file describing the ExtensionFeedItem service.

  Service to manage extension feed items.
  """

  def GetExtensionFeedItem(self, request, context):
    """Returns the requested extension feed item in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateExtensionFeedItems(self, request, context):
    """Creates, updates, or removes extension feed items. Operation
    statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ExtensionFeedItemServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetExtensionFeedItem': grpc.unary_unary_rpc_method_handler(
          servicer.GetExtensionFeedItem,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_extension__feed__item__service__pb2.GetExtensionFeedItemRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_extension__feed__item__pb2.ExtensionFeedItem.SerializeToString,
      ),
      'MutateExtensionFeedItems': grpc.unary_unary_rpc_method_handler(
          servicer.MutateExtensionFeedItems,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_extension__feed__item__service__pb2.MutateExtensionFeedItemsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_extension__feed__item__service__pb2.MutateExtensionFeedItemsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.ExtensionFeedItemService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
